@@ -4,10 +4,8 @@ import argparse
 import colorama
 from colorama import Fore, Style
 
-import freepaths.main_tracing
-import freepaths.main_mfp_sampling
 
-__version__ = "2.1"
+__version__ = "2.2"
 
 colorama.init()
 
@@ -19,6 +17,7 @@ parser = argparse.ArgumentParser(
                 )
 parser.add_argument('input_file', nargs='?', default=None, help='The input file')
 parser.add_argument("-s", "--sampling", help="Run in MFP sampling mode", action="store_true")
+parser.add_argument("-e", "--electron", help="Run simulation for electrons", action="store_true")
 args = parser.parse_args()
 
 
@@ -26,9 +25,18 @@ def run():
     """Run the program depending on the mode"""
     print(f"\n{Fore.BLUE}FreePATHS v{__version__}{Style.RESET_ALL}")
     if args.sampling:
+        import freepaths.main_mfp_sampling
         freepaths.main_mfp_sampling.main(args.input_file)
+
+    elif args.electron:
+        import freepaths.main_tracing
+        from freepaths.particle_types import ParticleType
+        freepaths.main_tracing.main(args.input_file, ParticleType.ELECTRON)
+
     else:
-        freepaths.main_tracing.main(args.input_file)
+        import freepaths.main_tracing
+        from freepaths.particle_types import ParticleType
+        freepaths.main_tracing.main(args.input_file, ParticleType.PHONON)
 
 
 if __name__ == "__main__":
