@@ -6,6 +6,7 @@ checks the validity of the parameters and converts the variables into enums
 import sys
 import argparse
 import logging
+import builtins #24/06
 from colorama import Fore, Style
 
 from freepaths.sources import Distributions
@@ -24,6 +25,7 @@ parser = argparse.ArgumentParser(prog='FreePATHS', description='Monte Carlo simu
                                  epilog=f'For more information, visit: {WEBSITE}')
 parser.add_argument('input_file', nargs='?', default=None, help='The input file')
 parser.add_argument("-s", "--sampling", help="Run in MFP sampling mode", action="store_true")
+parser.add_argument("-e", "--electron", help="Run with electrons", action="store_true")
 args = parser.parse_args()
 
 
@@ -46,13 +48,14 @@ class Config:
 
         # General parameters:
         self.output_folder_name = str(OUTPUT_FOLDER_NAME)
-        self.number_of_phonons = NUMBER_OF_PHONONS
+        self.number_of_particles = NUMBER_OF_PARTICLES
         self.number_of_nodes = NUMBER_OF_NODES
         self.temp = T
         self.output_scattering_map = OUTPUT_SCATTERING_MAP
         self.output_trajectories_of_first = OUTPUT_TRAJECTORIES_OF_FIRST
         self.output_structure_color = OUTPUT_STRUCTURE_COLOR
         self.number_of_length_segments = NUMBER_OF_LENGTH_SEGMENTS
+        self.low_memory_usage = LOW_MEMORY_USAGE
 
         # Time parameters:
         self.timestep = TIMESTEP
@@ -60,6 +63,14 @@ class Config:
         self.number_of_timeframes = NUMBER_OF_TIMEFRAMES
         self.number_of_stabilization_timeframes = NUMBER_OF_STABILIZATION_TIMEFRAMES
 
+        # Electron parameters:
+        self.energy_upper_bound = ENERGY_UPPER_BOUND
+        self.energy_lower_bound = ENERGY_LOWER_BOUND
+        self.energy_step = ENERGY_STEP
+        self.electron_mfp = ELECTRON_MFP
+        self.mean_mapping_constant = MEAN_MAPPING_CONSTANT
+        self.is_carrier_electron = IS_CARRIER_ELECTRON
+
         # Animation:
         self.output_path_animation = OUTPUT_PATH_ANIMATION
         self.output_animation_fps = OUTPUT_ANIMATION_FPS
@@ -68,10 +79,11 @@ class Config:
         self.number_of_pixels_x = NUMBER_OF_PIXELS_X
         self.number_of_pixels_y = NUMBER_OF_PIXELS_Y
         self.number_of_virtual_timesteps = NUMBER_OF_VIRTUAL_TIMESTEPS
-        self.ignore_faulty_phonons = IGNORE_FAULTY_PHONONS
+        self.ignore_faulty_particles = IGNORE_FAULTY_PARTICLES
 
         # Material parameters:
         self.media = MEDIA
+        self.media_fermi_level = MEDIA_FERMI_LEVEL
 
         # Internal scattering:
         self.include_internal_scattering = INCLUDE_INTERNAL_SCATTERING
@@ -93,9 +105,10 @@ class Config:
         self.hot_side_position_bottom = HOT_SIDE_POSITION_BOTTOM
         self.hot_side_position_right = HOT_SIDE_POSITION_RIGHT
         self.hot_side_position_left = HOT_SIDE_POSITION_LEFT
+        self.rethermalization_on_hot_sides = RETHERMALIZATION_ON_HOT_SIDES
 
         # Sources:
-        self.phonon_sources = PHONON_SOURCES
+        self.particles_sources = PARTICLE_SOURCES
 
         # Cold side positions:
         self.cold_side_position_top = COLD_SIDE_POSITION_TOP
@@ -116,6 +129,7 @@ class Config:
         self.holes = HOLES
         self.pillars = PILLARS
         self.interfaces = INTERFACES
+        self.bulks = BULKS
 
         # Multiprocessing:
         self.num_workers = NUMBER_OF_PROCESSES
@@ -125,7 +139,7 @@ class Config:
 
         # Distributions:
         valid_distributions =[member.name.lower() for member in Distributions]
-        for source in self.phonon_sources:
+        for source in self.particles_sources:
             if source.angle_distribution in valid_distributions:
                 source.angle_distribution = Distributions[source.angle_distribution.upper()]
             else:
@@ -135,8 +149,8 @@ class Config:
 
     def check_parameter_validity(self):
         """Check if various parameters are valid"""
-        if self.number_of_phonons < self.output_trajectories_of_first:
-            self.output_trajectories_of_first = self.number_of_phonons
+        if self.number_of_particles < self.output_trajectories_of_first:
+            self.output_trajectories_of_first = self.number_of_particles
 
         if self.number_of_timeframes <= self.number_of_stabilization_timeframes:
             logging.error("Parameter NUMBER_OF_STABILIZATION_TIMEFRAMES exceeds or equal to NUMBER_OF_TIMEFRAMES.\n" +
@@ -144,7 +158,7 @@ class Config:
                           f"See the documentation at {WEBSITE}")
             sys.exit()
 
-        for source in self.phonon_sources:
+        for source in self.particles_sources:
             if source.y > self.length:
                 logging.error("Y coordinate of a source exceeded LENGHT")
                 sys.exit()
@@ -231,7 +245,18 @@ class Config:
                           f"See the documentation at {WEBSITE}")
             sys.exit()
 
+        if any([
+            'NUMBER_OF_PHONONS' in globals(),
+            'IGNORE_FAULTY_PHONONS' in globals(),
+            'PHONON_SOURCES' in globals(),
+        ]):
+            logging.error("Parameters NUMBER_OF_PHONONS, PHONON_SOURCES and IGNORE_FAULTY_PHONONS were deprecated.\n" +
+                          "Replace PHONONS with PARTICLES.\n" +
+                          f"See the documentation at {WEBSITE}")
+            sys.exit()
+
 cf = Config()
 cf.convert_to_enums()
 cf.check_parameter_validity()
 cf.check_depricated_parameters()
+
