@@ -15,26 +15,30 @@ class Data:
 
 
 class PathData(Data):
-    """Paths of phonons in space"""
+    """Paths of particles in space"""
 
     def __init__(self):
-        """Initialize arrays to save phonon paths"""
-        self.phonon_paths = []
+        """Initialize arrays to save particle paths"""
+        self.particle_paths = []
 
-    def save_phonon_path(self, flight):
+    def save_particle_path(self, flight):
         """Save the path to list of all paths"""
-        self.phonon_paths.append(flight.path)
+        if cf.low_memory_usage:
+            return
+        self.particle_paths.append(flight.path)
 
     @property
     def length_of_longest_path(self):
         """Calculate the number of points in the longest path"""
-        return max([path.number_of_path_points for path in self.phonon_paths])
+        return max([path.number_of_path_points for path in self.particle_paths])
 
     def write_into_files(self):
         """Write all the path coordinates into a file"""
-        filename = "Data/Phonon paths.csv"
-        data = np.zeros((self.length_of_longest_path, 3*len(self.phonon_paths)))
-        for index, path in enumerate(self.phonon_paths):
+        if cf.low_memory_usage:
+            return
+        filename = "Data/Particle paths.csv"
+        data = np.zeros((self.length_of_longest_path, 3*len(self.particle_paths)))
+        for index, path in enumerate(self.particle_paths):
             for point_n, (x, y, z) in enumerate(zip(path.x, path.y, path.z)):
                 data[point_n, 0 + index*3] = x*1e6
                 data[point_n, 1 + index*3] = y*1e6
@@ -43,11 +47,11 @@ class PathData(Data):
 
     def dump_data(self):
         """Return data of a process in the form of a dictionary to be attached to the global data"""
-        return {'phonon_paths': self.phonon_paths}
+        return {'particle_paths': self.particle_paths}
 
 
 class GeneralData(Data):
-    """General statistics of various phonon properties"""
+    """General statistics of various particle properties"""
 
     def __init__(self):
         """Initialize arrays for writing various properties"""
@@ -56,34 +60,50 @@ class GeneralData(Data):
         self.hole_diff_scattering_angles = []
         self.hole_spec_scattering_angles = []
         self.free_paths = []
-        self.free_paths_along_y = []
         self.frequencies = []
+        self.initial_energies = []
         self.group_velocities = []
         self.travel_times = []
         self.mean_free_paths = []
         self.thermal_conductivity = []
+        self.interfaces_angles = []
+        self.interfaces_transmission_factor = []
+        self.interfaces_wavelength = []
+        self.interfaces_frequency = []
+        self.interfaces_mode = []
 
-    def save_phonon_data(self, ph):
-        """Add information about the phonon to the dataset"""
-        self.frequencies.append(ph.f)
-        self.group_velocities.append(ph.speed)
+    def save_particle_data(self, pt):
+        """Add information about the particle to the dataset"""
+        self.frequencies.append(pt.f)
+        self.group_velocities.append(pt.speed)
+        self.initial_energies.append(pt.energy)
 
     def save_flight_data(self, flight):
-        """Add information about the phonon flight to the dataset"""
+        """Add information about the particle flight to the dataset"""
+        if not cf.low_memory_usage:
+            self.free_paths.extend(flight.free_paths)
         self.initial_angles.append(flight.initial_theta)
         self.exit_angles.append(flight.exit_theta)
-        self.free_paths.extend(flight.free_paths)
         self.hole_diff_scattering_angles.extend(flight.hole_diff_scattering_angles)
         self.hole_spec_scattering_angles.extend(flight.hole_spec_scattering_angles)
-        self.free_paths_along_y.extend(flight.free_paths_along_y)
         self.travel_times.append(flight.travel_time)
         self.mean_free_paths.append(flight.mean_free_path)
         self.thermal_conductivity.append(flight.thermal_conductivity)
+        self.interfaces_angles.extend(flight.interfaces_angles)
+        self.interfaces_transmission_factor.extend(flight.interfaces_transmission_factor)
+        self.interfaces_wavelength.extend(flight.interfaces_wavelength)
+        self.interfaces_frequency.extend(flight.interfaces_frequency)
+        self.interfaces_mode.extend(flight.interfaces_mode)
+
+
 
     def write_into_files(self):
+        import os
+        if not os.path.exists("Data"):
+            os.makedirs("Data")
         """Write all the data into files"""
-        np.savetxt("Data/All free paths.csv", self.free_paths, fmt='%2.4e', header="L [m]", encoding='utf-8')
-        np.savetxt("Data/All free paths in plane.csv", self.free_paths_along_y, fmt='%2.4e', header="Ly [m]", encoding='utf-8')
+        if not cf.low_memory_usage:
+            np.savetxt("Data/All free paths.csv", self.free_paths, fmt='%2.4e', header="L [m]", encoding='utf-8')
         np.savetxt("Data/All initial frequencies.csv", self.frequencies, fmt='%2.4e', header="f [Hz]", encoding='utf-8')
         np.savetxt("Data/All exit angles.csv", self.exit_angles, fmt='%.4f', header="Angle [rad]", encoding='utf-8')
         np.savetxt("Data/All hole diffuse scattering angles.csv", self.hole_diff_scattering_angles, fmt='%.4f', header="Angle [rad]", encoding='utf-8')
@@ -93,6 +113,12 @@ class GeneralData(Data):
         np.savetxt("Data/All travel times.csv", self.travel_times, fmt='%2.4e', header="Travel time [s]", encoding='utf-8')
         np.savetxt("Data/All mean free paths.csv", self.mean_free_paths, fmt='%2.4e', header="MFPs [m]", encoding='utf-8')
         np.savetxt("Data/All thermal conductivities.csv", self.thermal_conductivity, fmt='%2.4e', header="K [W/mK]", encoding='utf-8')
+        np.savetxt("Data/All initial energies.csv", self.initial_energies, fmt='%2.4e', header="Energy [J]", encoding='utf-8')
+        np.savetxt("Data/All interfaces angles.csv", self.interfaces_angles, fmt='%.4f', header="Angle [rad]", encoding='utf-8')
+        np.savetxt("Data/All interfaces transmission factor.csv", self.interfaces_transmission_factor, fmt='%2.4e', header="Transmission factor [%]", encoding='utf-8')
+        np.savetxt("Data/All interfaces wavelength.csv", self.interfaces_wavelength, fmt='%.18f', header="Interfaces wavelength [m]", encoding='utf-8')
+        np.savetxt("Data/All interfaces frequency.csv", self.interfaces_frequency, fmt='%.18f', header="Interfaces frequency [THz]", encoding='utf-8')
+        np.savetxt("Data/All interfaces mode.csv", self.interfaces_mode, fmt='%d', header="Interfaces mode", encoding='utf-8')
 
     def dump_data(self):
         """Return data of a process in the form of a dictionary to be attached to the global data"""
@@ -102,17 +128,23 @@ class GeneralData(Data):
             'hole_diff_scattering_angles': self.hole_diff_scattering_angles,
             'hole_spec_scattering_angles': self.hole_spec_scattering_angles,
             'free_paths': self.free_paths,
-            'free_paths_along_y': self.free_paths_along_y,
             'frequencies': self.frequencies,
             'group_velocities': self.group_velocities,
             'travel_times': self.travel_times,
             'mean_free_paths': self.mean_free_paths,
             'thermal_conductivity': self.thermal_conductivity,
+            'initial_energies': self.initial_energies,
+            'interfaces_angles': self.interfaces_angles,
+            'interfaces_transmission_factor': self.interfaces_transmission_factor,
+            'interfaces_wavelength': self.interfaces_wavelength,
+            'interfaces_frequency': self.interfaces_frequency,
+            'interfaces_mode': self.interfaces_mode,
         }
 
 
+
 class ScatteringData(Data):
-    """Statistics of phonon scattering events"""
+    """Statistics of particle scattering events"""
 
     def __init__(self):
         """Initialize arrays according to the number of segments"""
@@ -129,6 +161,15 @@ class ScatteringData(Data):
         self.interfaces_diffuse = np.zeros(cf.number_of_length_segments+1)
         self.interfaces_specular = np.zeros(cf.number_of_length_segments+1)
         self.total = np.zeros(cf.number_of_length_segments+1)
+        self.interfaces_transmission_specular= np.zeros(cf.number_of_length_segments + 1)
+        self.interfaces_transmission_diffuse = np.zeros(cf.number_of_length_segments + 1)
+        self.interfaces_angles = np.zeros(cf.number_of_length_segments + 1)
+        self.interfaces_transmission_factor = np.zeros(cf.number_of_length_segments + 1)
+        self.interfaces_wavelength = np.zeros(cf.number_of_length_segments+1)
+        self.interfaces_frequency = np.zeros(cf.number_of_length_segments+1)
+        self.interfaces_mode = np.zeros(cf.number_of_length_segments+1)
+
+
 
     def save_scattering_events(self, y, scattering_types):
         """Analyze types of scattering at the current timestep and add it to the statistics"""
@@ -161,6 +202,10 @@ class ScatteringData(Data):
             # Internal scattering and rethermalization on hot side:
             self.hot_side[segment] += 1 if scattering_types.hot_side == Scattering.DIFFUSE else 0
             self.internal[segment] += 1 if scattering_types.internal == Scattering.DIFFUSE else 0
+
+            # Interfaces transmission events:
+            self.interfaces_transmission_specular[segment] += 1 if scattering_types.interfaces_transmission== Scattering.SPECULAR else 0
+            self.interfaces_transmission_diffuse[segment] += 1 if scattering_types.interfaces_transmission == Scattering.DIFFUSE else 0
         except:
             pass
 
@@ -168,10 +213,16 @@ class ScatteringData(Data):
         """Write data into a file"""
         filename = "Data/Scattering events statistics.csv"
         data = np.vstack((self.wall_diffuse, self.wall_specular, self.top_diffuse, self.top_specular, self.hole_diffuse,
-                        self.hole_specular, self.hot_side, self.internal, self.pillar_diffuse, self.pillar_specular)).T
+                        self.hole_specular, self.hot_side, self.internal, self.pillar_diffuse, self.pillar_specular,
+                        self.interfaces_diffuse, self.interfaces_specular,
+                        self.interfaces_transmission_diffuse, self.interfaces_transmission_specular,
+                        self.interfaces_transmission_factor, self.interfaces_angles,
+                        self.interfaces_wavelength, self.interfaces_mode)).T
         header1 = "Sidewalls diffuse, Sidewalls specular, Top & bottom diffuse, Top & bottom specular, "
         header2 = "Holes diffuse, Holes specular, Hot side, Internal, Pillars diffuse, Pillars specular"
-        header = header1 + header2
+        header3 = "Interfaces diffuse, Interfaces specular, Interfaces transmission diffuse, Interfaces transmission specular, " \
+        "Interfaces transmission factor, Interfaces angles, Interfaces wavelength, Interfaces frequency, Interfaces mode"
+        header = header1 + header2 + header3
         np.savetxt(filename, data, fmt='%1.3e', delimiter=",", header=header, encoding='utf-8')
 
     def dump_data(self):
@@ -189,12 +240,19 @@ class ScatteringData(Data):
             'internal': self.internal,
             'interfaces_diffuse': self.interfaces_diffuse,
             'interfaces_specular': self.interfaces_specular,
+            'interfaces_transmission_specular': self.interfaces_transmission_specular,
+            'interfaces_transmission_diffuse': self.interfaces_transmission_diffuse,
+            'interfaces_angles': self.interfaces_angles,
+            'interfaces_transmission_factor': self.interfaces_transmission_factor,
+            'interfaces_wavelength': self.interfaces_wavelength,
+            'interfaces_frequency': self.interfaces_frequency,
+            'interfaces_mode' : self.interfaces_mode,
             'total': self.total
         }
 
 
 class TriangleScatteringData(Data):
-    """Statistics of phonon scattering events on triangular holes"""
+    """Statistics of particle scattering events on triangular holes"""
 
     def __init__(self):
         """Initialize arrays according to the number of segments"""
@@ -255,7 +313,7 @@ class SegmentData(Data):
         return segments
 
     def record_time_in_segment(self, coordinate):
-        """Record how long phonon stays in different segments"""
+        """Record how long particle stays in different segments"""
         for segment_number in range(cf.number_of_length_segments):
             segment_beginning = segment_number * (cf.length / cf.number_of_length_segments)
             segment_end = (segment_number + 1)*(cf.length / cf.number_of_length_segments)
