@@ -1,18 +1,20 @@
 """Default config file"""
 
 import numpy as np
+from scipy.constants import k, electron_volt
 from freepaths.sources import Source
 
 
 # General parameters:
 OUTPUT_FOLDER_NAME               = "Si nanowire at 300 K"
-NUMBER_OF_PHONONS                = 5000
+NUMBER_OF_PARTICLES              = 5000
 NUMBER_OF_NODES                  = 400
 T                                = 300
 OUTPUT_SCATTERING_MAP            = False
 OUTPUT_TRAJECTORIES_OF_FIRST     = 50
 OUTPUT_STRUCTURE_COLOR           = "#F0F0F0"
 NUMBER_OF_LENGTH_SEGMENTS        = 10
+LOW_MEMORY_USAGE                 = False
 
 # Time parameters:
 TIMESTEP                         = 1e-12
@@ -21,6 +23,15 @@ NUMBER_OF_VIRTUAL_TIMESTEPS      = NUMBER_OF_TIMESTEPS * 3
 NUMBER_OF_TIMEFRAMES             = 8
 NUMBER_OF_STABILIZATION_TIMEFRAMES = 5
 
+# Electron parameters [eV]
+IS_CARRIER_ELECTRON              = True
+ENERGY_UPPER_BOUND               = 3*k*T / electron_volt
+ENERGY_LOWER_BOUND               = 0
+ENERGY_STEP                      = 5e-3
+
+ELECTRON_MFP                     = 15e-9 # [m]
+MEAN_MAPPING_CONSTANT            = 5e-6 # [m²]
+
 
 # Animation:
 OUTPUT_PATH_ANIMATION            = False
@@ -29,10 +40,11 @@ OUTPUT_ANIMATION_FPS             = 24
 # Map & profiles parameters:
 NUMBER_OF_PIXELS_X               = 25
 NUMBER_OF_PIXELS_Y               = 100
-IGNORE_FAULTY_PHONONS            = False
+IGNORE_FAULTY_PARTICLES          = False
 
 # Material parameters:
 MEDIA                            = "Si"
+MEDIA_FERMI_LEVEL                = None
 
 # Internal scattering:
 INCLUDE_INTERNAL_SCATTERING      = True
@@ -58,9 +70,10 @@ HOT_SIDE_POSITION_TOP            = False
 HOT_SIDE_POSITION_BOTTOM         = True
 HOT_SIDE_POSITION_RIGHT          = False
 HOT_SIDE_POSITION_LEFT           = False
+RETHERMALIZATION_ON_HOT_SIDES    = True
 
-# Phonon source:
-PHONON_SOURCES = [Source(x=0, y=0, z=0, size_x=0,  size_y=0, size_z=0, angle_distribution="random", angle=0)]
+# Particle source:
+PARTICLE_SOURCES = [Source(x=0, y=0, z=0, size_x=0,  size_y=0, size_z=0, angle_distribution="random", angle=0)]
 
 # Roughness [m]:
 SIDE_WALL_ROUGHNESS              = 2e-9
@@ -75,6 +88,7 @@ INTERFACE_ROUGHNESS              = 0.2e-9
 HOLES                            = []
 PILLARS                          = []
 INTERFACES                       = []
+BULKS                            = [] 
 
 # Multiprocessing:
 NUMBER_OF_PROCESSES              = 10
