@@ -12,12 +12,12 @@ from colorama import Fore, Style
 # Modules:
 from freepaths.animation import create_animation
 from freepaths.config import cf
-from freepaths.run_phonon import run_phonon
+from freepaths.run_particle import run_particle
 from freepaths.phonon import Phonon
 from freepaths.flight import Flight
 from freepaths.data import ScatteringData, GeneralData, SegmentData, PathData, TriangleScatteringData
 from freepaths.progress import Progress
-from freepaths.materials import Si, SiC, Graphite
+from freepaths.materials import Si, SiC, Graphite, Ge 
 from freepaths.maps import ScatteringMap, ThermalMaps
 from freepaths.output_info import output_general_information, output_scattering_information, output_parameter_warnings
 from freepaths.output_plots import plot_data
@@ -32,11 +32,17 @@ def main(input_file):
 
     # Initialize the material:
     if cf.media == "Si":
-        material = Si(cf.temp, num_points=cf.number_of_phonons +1)
+        material = Si(cf.temp, num_points=cf.number_of_particles +1)
+
+# -------- has to be modified fro have only SiGe values and not a mix between Ge and SiGe------------
+    elif cf.media == "Ge":
+        material = Ge(cf.temp, num_points=cf.number_of_particles +1) 
+# -------- has to be modified fro have only SiGe values and not a mix between Ge and SiGe------------
+
     elif cf.media == "SiC":
-        material = SiC(cf.temp, num_points=cf.number_of_phonons+1)
+        material = SiC(cf.temp, num_points=cf.number_of_particles+1)
     elif cf.media == "Graphite":
-        material = Graphite(cf.temp, num_points=cf.number_of_phonons+1)
+        material = Graphite(cf.temp, num_points=cf.number_of_particles+1)
     else:
         logging.error(f"Material {cf.media} is not supported")
         sys.exit()
@@ -57,7 +63,7 @@ def main(input_file):
         sys.stdout.write(f"\rIntegrating branch number {branch_number+1}.\n")
 
         # For each phonon:
-        for index in range(cf.number_of_phonons):
+        for index in range(cf.number_of_particles):
 
             # Wave vector:
             k_vector = (material.dispersion[index+1, 0] + material.dispersion[index, 0]) / 2
@@ -68,7 +74,7 @@ def main(input_file):
             flight = Flight(phonon)
 
             # Run this phonon through the structure:
-            run_phonon(phonon, flight, scatter_stats, places_stats, segment_stats, thermal_maps, scatter_maps, material)
+            run_particle(phonon, flight, scatter_stats, places_stats, segment_stats, thermal_maps, scatter_maps, material)
 
             # Heat capacity, Ref. PRB 88 155318 (2013):
             omega = 2 * math.pi * phonon.f
@@ -81,12 +87,12 @@ def main(input_file):
             total_thermal_conductivity += flight.thermal_conductivity
 
             # Record the properties returned for this phonon:
-            general_stats.save_phonon_data(phonon)
+            general_stats.save_particle_data(phonon)
             general_stats.save_flight_data(flight)
 
             # Record trajectories of the first N phonons:
             if index < cf.output_trajectories_of_first:
-                path_stats.save_phonon_path(flight)
+                path_stats.save_particle_path(flight)
 
     # Run additional calculations:
     thermal_maps.calculate_thermal_conductivity()
@@ -115,7 +121,7 @@ def main(input_file):
 
     # Analyze and plot the data:
     sys.stdout.write("\rAnalyzing the data...")
-    plot_data(mfp_sampling=True)
+    plot_data(particle_type, cf, mfp_sampling=True)
 
     # Output general information:
     output_general_information(start_time)
