@@ -1,31 +1,28 @@
 """This module provides phonon class which generates and moves a phonon"""
 
-from math import pi, asin, exp, log
-from random import random, choice, randint
+from math import pi, exp, log
+from random import random, choice
 from numpy import sign
-from scipy.constants import k, hbar
+from scipy.constants import k, hbar, h
 import numpy as np
-import enum
 
 from freepaths.config import cf
+from freepaths.particle_types import ParticleType
+from freepaths.particle import Particle
 import freepaths.move
 
 
-class Phonon:
+class Phonon(Particle):
     """A phonon particle with various physical properties"""
 
     def __init__(self, material, branch_number=None, phonon_number=None):
         """Initialize a phonon by assigning initial properties"""
+        super().__init__()
+        # Assign particle type
+        self.type = ParticleType.PHONON
+        
         self.branch_number = branch_number
         self.phonon_number = phonon_number
-        self.x = None
-        self.y = None
-        self.z = None
-        self.f = None
-        self.phi = None
-        self.theta = None
-        self.speed = None
-        self.first_timestep = randint(0, cf.number_of_virtual_timesteps)
 
         # Assign initial properties of the phonon:
         if self.branch_number is None:
@@ -33,7 +30,7 @@ class Phonon:
         self.f_max = max(material.dispersion[:, self.branch_number + 1])
 
         # Assign initial coordinates but ensure that it's not inside a hole:
-        source = choice(cf.phonon_sources)
+        source = choice(cf.particles_sources)
         while True:
             self.x, self.y, self.z = source.generate_coordinates()
             is_in_hole = any(hole.is_inside(self.x, self.y, None, cf) for hole in cf.holes)
@@ -66,17 +63,9 @@ class Phonon:
         return self.speed / self.f
 
     @property
-    def is_in_system(self):
-        """Checks if the phonon at this timestep did not reach the cold side.
-        Depending on where user set cold sides, we check if phonon crossed that line"""
-        is_inside_top = self.y < cf.length
-        is_inside_bottom = self.y > 0
-        is_inside_right = self.x < cf.width / 2.0
-        is_inside_left = self.x > - cf.width / 2.0
-        return ((not cf.cold_side_position_top or is_inside_top) and
-                (not cf.cold_side_position_bottom or is_inside_bottom) and
-                (not cf.cold_side_position_right or is_inside_right) and
-                (not cf.cold_side_position_left or is_inside_left))
+    def energy(self):
+        """Calculate energy of the phonon"""
+        return self.f * h
 
     def assign_frequency(self, material):
         """Assigning frequency with probability according to Planckian distribution"""
@@ -119,7 +108,7 @@ class Phonon:
         else:
             # Relaxation time is assigned with some randomization [PRB 94, 174303 (2016)]:
             omega = 2 * pi * self.f
-            self.time_of_internal_scattering = -log(random()) * material.relaxation_time(omega)
+            self.time_of_internal_scattering = -log(random()) * material.phonon_relaxation_time(omega)
 
     def move(self):
         """Move a phonon in one timestep and return new coordinates"""
