@@ -9,9 +9,9 @@ class Progress:
     def __init__(self):
         self.percentage = -1
 
-    def render(self, phonon_number, number_of_phonons):
+    def render(self, particle_number, number_of_particles):
         """Check if percentage increased since last iteration and display the progress"""
-        new_percentage = 100 * phonon_number // number_of_phonons
+        new_percentage = 100 * particle_number // number_of_particles
         if new_percentage > self.percentage:
             self.percentage = new_percentage
             sys.stdout.write('\r' + 'Progress: ' + str(self.percentage) + '%')
