@@ -1,5 +1,5 @@
 """
-Module that provides types of phonon scattering that might occur.
+Module that provides types of particle scattering that might occur.
 These scattering types are returned on each step
 so that higher level modules know what has happened.
 """
@@ -14,7 +14,7 @@ class Scattering(enum.Enum):
 
 
 class ScatteringTypes:
-    """Phonon scattering types"""
+    """particle scattering types"""
 
     def __init__(self):
         """Initialize possible scattering type"""
@@ -25,6 +25,10 @@ class ScatteringTypes:
         self.internal = None
         self.hot_side = None
         self.interfaces = None
+        self.interfaces_transmission_diffuse = None 
+        self.interfaces_transmission_specular = None 
+        self.interfaces_transmission = None 
+
 
     @property
     def is_diffuse(self):
@@ -34,7 +38,9 @@ class ScatteringTypes:
                     self.top_bottom == Scattering.DIFFUSE,
                     self.walls == Scattering.DIFFUSE,
                     self.hot_side == Scattering.DIFFUSE,
-                    self.interfaces == Scattering.DIFFUSE])
+                    self.interfaces == Scattering.DIFFUSE,
+                    self.interfaces_transmission == Scattering.DIFFUSE, 
+                    ])
 
     @property
     def is_internal(self):
@@ -50,6 +56,16 @@ class ScatteringTypes:
     def is_specular_on_hole(self):
         """Was there a specular scattering on holes?"""
         return self.holes == Scattering.SPECULAR
+    
+    @property
+    def transmission_is_diffuse(self):
+        """Was there a diffuse scattering on holes?"""
+        return self.interfaces_transmission == Scattering.DIFFUSE
+
+    @property
+    def transmission_is_specular(self):
+        """Was there a specular scattering on holes?"""
+        return self.interfaces_transmission == Scattering.SPECULAR
 
     @property
     def is_scattered(self):
@@ -60,7 +76,9 @@ class ScatteringTypes:
                     self.walls,
                     self.internal,
                     self.hot_side,
-                    self.interfaces])
+                    self.interfaces,
+                    self.interfaces_transmission, 
+                    ])
 
     def reset(self):
         """Reset all scattering types to None"""
@@ -71,10 +89,13 @@ class ScatteringTypes:
         self.internal = None
         self.hot_side = None
         self.interfaces = None
+        self.interfaces_transmission = None 
+        self.interfaces_transmission_diffuse = None 
+        self.interfaces_transmission_specular = None 
 
 
 class ScatteringPlaces:
-    """Phonon scattering places on a triangle"""
+    """particle scattering places on a triangle"""
 
     def __init__(self):
         """Initialize possible scattering places"""
